"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function sleep(time) {
    return new Promise(r => {
        setTimeout(r, time);
    });
}
class Cached extends Map {
    constructor(time = 5000) {
        super();
        this.time = time;
        this._keys = [];
    }
    async start() {
        let tmp;
        while (true) {
            if (tmp) {
                const now = Date.now();
                if (now - tmp.ex >= 0) {
                    this.delete(tmp.key);
                    tmp = this._keys.shift();
                    continue;
                }
            }
            else {
                tmp = this._keys.shift();
            }
            await sleep(this.time);
        }
    }
    set(key, value) {
        const rs = super.set(key, value);
        this._keys.push({ key, ex: Date.now() + this.time });
        return rs;
    }
    clear() {
        this._keys.splice(0, this._keys.length);
        super.clear();
    }
    end() {
        clearInterval(this.tm);
    }
}
exports.Cached = Cached;
